@@ -10,6 +10,7 @@ __all__ = [
     "TournamentEA",
     "IOPIS_NSGAIII",
     "IOPIS_RVEA",
+    "MOEA_D",
 ]
 
 from desdeo_emo.EAs.BaseEA import BaseEA, BaseDecompositionEA
@@ -17,4 +18,5 @@ from desdeo_emo.EAs.RVEA import RVEA
 from desdeo_emo.EAs.NSGAIII import NSGAIII
 from desdeo_emo.EAs.PPGA import PPGA
 from desdeo_emo.EAs.TournamentEA import TournamentEA
-from desdeo_emo.EAs.IOPIS import IOPIS_NSGAIII, IOPIS_RVEA
\ No newline at end of file
+from desdeo_emo.EAs.IOPIS import IOPIS_NSGAIII, IOPIS_RVEA
+from desdeo_emo.EAs.MOEAD import MOEA_D
